@echo off

rem ********************************************************************************
rem *
rem * GENTXTMD.BAT
rem *
rem * This file dynamically generates the textmode directory for the set of device
rem * drivers copied to the NOS partition by copysgdd.bat for the ServerGuide 
rem * Scripting Toolkit.  
rem *
rem * This batch file is called by the instos.bat.
rem *
rem ********************************************************************************


rem ********************************************************************************
rem * Change to the target path
rem ********************************************************************************
%NOSDRV%
cd \%WRK_DIR%

rem ********************************************************************************
rem * Store the machine type as an environment variable
rem ********************************************************************************
CLIni.exe HWDetect.ini /S:System /I:Machine_Type /E:MACHTYPE

rem ********************************************************************************
rem Check for errors: CLINI.EXE
rem ********************************************************************************
if not errorlevel 1 goto RUNBAT1
echo An error occurred running clini.exe on HWDetect.ini.
goto ERROR

:RUNBAT1
call CLIniSet.bat

rem ********************************************************************************
rem * Store the Windows version of the device drivers as an environment variable
rem ********************************************************************************
CLIni.exe $oem$\$1\drv\DrvSet.ini /S:Main /I:Windows Version /E:OS_VER

rem ********************************************************************************
rem Check for errors: CLINI.EXE
rem ********************************************************************************
if not errorlevel 1 goto RUNBAT2
echo An error occurred running clini.exe on $oem$\$1\drv\DrvSet.ini.
echo.
goto ERROR


:RUNBAT2
rem ********************************************************************************
rem * Set the environment variable
rem ********************************************************************************
call CLIniSet.bat


:CUSTDRVS
rem ********************************************************************************
rem *  Custom driver modifications
rem ********************************************************************************

for %%i in (8485,8490,1887,8491,8849) do if "%MACHTYPE%" == "%%i" goto CUSTDRV1
goto CUSTDRV2


:CUSTDRV1
rem ********************************************************************************
rem *  HRSAS and SAS drivers cannot coexist in the unattended install.
rem *  If HostRAID is turned off in the BIOS, then the PCI Ven/Dev ID
rem *  is 9005/043E.  If it is turned on then it is 9005/043F.
rem ********************************************************************************
HWDetect.exe /VID:9005 /DID:043E
if errorlevel 1 goto REMHRSAS
goto REMSAS

:REMHRSAS
echo y | deltree $oem$\$1\drv\hrsas > nul
goto CUSTDRV2

:REMSAS
echo y | deltree $oem$\$1\drv\sas > nul
goto CUSTDRV2


:CUSTDRV2
rem ********************************************************************************
rem *  Windows Server 2003 with SP 1 requires that the custom HAL be
rem *  removed for the 8870 and the SRSATA drivers removed for all systems
rem *  from the driver set prior to installation.
rem ********************************************************************************
if not "%OS_VER%"=="Win2003Server" goto DSCAN


:CHKFORSP
xcopy %OS_PATH%\i386\txtsetup.sif .

CLIni.exe txtsetup.sif /S:Strings /I:spcdname /E:SPCDNAME

rem ********************************************************************************
rem *  Check for errors: CLINI.EXE
rem ********************************************************************************
if not errorlevel 1 goto RUNBAT3
echo An error occurred running clini.exe on txtsetup.sif.
echo.
goto ERROR

:RUNBAT3
call CLIniset.bat

del txtsetup.sif > nul

if "%SPCDNAME%" == "" goto DSCAN

set SPCDNAME=


rem ********************************************************************************
rem *  Remove the SRSATA drivers for all systems if W03 EE w/ SP 1 is
rem *  detected.
rem ********************************************************************************
echo y | deltree $oem$\$1\drv\srsata > nul


for %%i in (8870) do if "%MACHTYPE%" == "%%i" goto REMHAL
goto DSCAN


:REMHAL              
echo y | deltree $oem$\$1\drv\hal > nul
goto DSCAN


:DSCAN
rem ********************************************************************************
rem * Dynamically create the $oem$\textmode directory for this machine type
rem ********************************************************************************
DScan.exe $OEM$\$1\DRV /T /M:%MACHTYPE% /V:2 /W:%OS_VER%


rem ********************************************************************************
rem * Check for errors: DSCAN.EXE
rem ********************************************************************************
if not errorlevel 1 goto END
echo An error occurred running dscan.exe.
echo.
goto ERROR


:ERROR
rem ********************************************************************************
rem * Hit an error in this batch file.
rem ********************************************************************************
echo Encountered an error and stopped processing in "gentxtmd.bat".

savestat.exe /set2=251 > nul

goto END


:END

